@@ -84,7 +84,7 @@ class _CreateCategoricalEncodedVariables(DoFn):
         # Multi Label Binarizer Variables
         # Split out Equipment Types
         df["equipment_type_list"] = df["equipment_type_list"].str.split(pat=", ")
-        df.equipment_types_list.fillna(value=u'', inplace=True)
+        df.equipment_type_list.fillna(value=u'', inplace=True)
 
         # Equipment Types
         df["equipment_type_encoded"] = list(self.load_equipment_mlb.transform(df["equipment_type_list"]))
